BasicBlock

Enum BasicBlock 

pub enum BasicBlock<'blk> {
Show 16 variants Undefined, Root(&'blk BlockRoot<'blk>), Module(&'blk BlockModule<'blk>), Func(&'blk BlockFunc<'blk>), Call(&'blk BlockCall<'blk>), Enum(&'blk BlockEnum<'blk>), Class(&'blk BlockClass<'blk>), Trait(&'blk BlockTrait<'blk>), Interface(&'blk BlockInterface<'blk>), Impl(&'blk BlockImpl<'blk>), Const(&'blk BlockConst<'blk>), Field(&'blk BlockField<'blk>), Parameter(&'blk BlockParameter<'blk>), Return(&'blk BlockReturn<'blk>), Alias(&'blk BlockAlias<'blk>), Block,
}

Variants



Undefined



Root(&'blk BlockRoot<'blk>)



Module(&'blk BlockModule<'blk>)



Func(&'blk BlockFunc<'blk>)



Call(&'blk BlockCall<'blk>)



Enum(&'blk BlockEnum<'blk>)



Class(&'blk BlockClass<'blk>)



Trait(&'blk BlockTrait<'blk>)



Interface(&'blk BlockInterface<'blk>)



Impl(&'blk BlockImpl<'blk>)



Const(&'blk BlockConst<'blk>)



Field(&'blk BlockField<'blk>)



Parameter(&'blk BlockParameter<'blk>)



Return(&'blk BlockReturn<'blk>)



Alias(&'blk BlockAlias<'blk>)



Block

Implementations

Source

impl<'blk> BasicBlock<'blk>

pub fn format_block(&self, unit: CompileUnit<'blk>) -> String

Format the block label (content inside the parentheses) Delegates to each block type’s format method

pub fn format_deps(&self, unit: CompileUnit<'blk>) -> Vec<String>

Format extra entries for dependencies (rendered as pseudo-children) Only applicable to Func and Class blocks, returns empty for others

pub fn format_suffix(&self) -> Option<String>

Format the suffix to appear after the closing parenthesis (Currently unused - type info is now inline in format_block)

pub fn id(&self) -> BlockId

pub fn base(&self) -> Option<&BlockBase<'blk>>

Get the base block information regardless of variant

pub fn block_id(&self) -> BlockId

Get the block ID

pub fn kind(&self) -> BlockKind

Get the block kind

pub fn node(&self) -> &HirNode<'blk>

Get the HIR node

pub fn opt_node(&self) -> Option<&HirNode<'blk>>

pub fn symbol(&self) -> Option<&'blk Symbol>

Get the symbol that defines this block (if any)

pub fn children(&self) -> Vec<BlockId>

Get the children block IDs

pub fn child_count(&self) -> usize

pub fn is_kind(&self, kind: BlockKind) -> bool

Check if this is a specific kind of block

pub fn as_root(&self) -> Option<&'blk BlockRoot<'blk>>

Get the inner BlockRoot if this is a Root block

pub fn as_module(&self) -> Option<&'blk BlockModule<'blk>>

Get the inner BlockModule if this is a Module block

pub fn as_func(&self) -> Option<&'blk BlockFunc<'blk>>

Get the inner BlockFunc if this is a Func or Method block

pub fn as_class(&self) -> Option<&'blk BlockClass<'blk>>

Get the inner BlockClass if this is a Class block

pub fn as_trait(&self) -> Option<&'blk BlockTrait<'blk>>

Get the inner BlockTrait if this is a Trait block

pub fn as_interface(&self) -> Option<&'blk BlockInterface<'blk>>

Get the inner BlockInterface if this is an Interface block

pub fn as_impl(&self) -> Option<&'blk BlockImpl<'blk>>

Get the inner BlockImpl if this is an Impl block

pub fn as_enum(&self) -> Option<&'blk BlockEnum<'blk>>

Get the inner BlockEnum if this is an Enum block

pub fn as_field(&self) -> Option<&'blk BlockField<'blk>>

Get the inner BlockField if this is a Field block

pub fn as_call(&self) -> Option<&'blk BlockCall<'blk>>

Get the inner BlockCall if this is a Call block