BlockArena

Struct BlockArena 

pub struct BlockArena<'a> { /* private fields */ }
Shared wrapper around ArenaInner, safely cloneable across threads.

Implementations

Source

impl<'a> BlockArena<'a>

pub fn new() -> Self

Create a new shared Arena.

pub fn inner_arc(&self) -> &Arc<ArenaInner>

Get the internal Arc.

Methods from Deref<Target = ArenaInner>

pub fn reset(&mut self)

Clear all allocations and reset memory.

pub fn alloc_with_id<'a, T: ArenaInsertWithId<'a>>( &'a self, id: usize, value: T, ) -> &'a T

Thread-safe allocation with ID for lookup. Allocates in bump arena and inserts into DashMap.

pub fn alloc<'a, T: ArenaInsert<'a>>(&'a self, value: T) -> &'a T

Thread-safe allocation without ID tracking. Just allocates in bump arena, no DashMap insert.

pub fn alloc_in_herd<T>(&self, value: T) -> &T

Allocate a value in the thread-local bump allocator. Uses thread_local to cache the Member per thread, avoiding mutex contention.

pub fn alloc_str(&self, src: &str) -> &str

Allocate a string in the thread-local bump allocator. Returns a reference to the arena-allocated string, avoiding heap allocation.

pub fn get_bb<'a>(&'a self, id: usize) -> Option<&'a BasicBlock<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_bb(&self) -> usize

Get count of items.

pub fn iter_bb<'a>(&'a self) -> impl Iterator<Item = &'a BasicBlock<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_root<'a>(&'a self, id: usize) -> Option<&'a BlockRoot<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_root(&self) -> usize

Get count of items.

pub fn iter_blk_root<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockRoot<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_module<'a>(&'a self, id: usize) -> Option<&'a BlockModule<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_module(&self) -> usize

Get count of items.

pub fn iter_blk_module<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockModule<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_func<'a>(&'a self, id: usize) -> Option<&'a BlockFunc<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_func(&self) -> usize

Get count of items.

pub fn iter_blk_func<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockFunc<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_class<'a>(&'a self, id: usize) -> Option<&'a BlockClass<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_class(&self) -> usize

Get count of items.

pub fn iter_blk_class<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockClass<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_trait<'a>(&'a self, id: usize) -> Option<&'a BlockTrait<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_trait(&self) -> usize

Get count of items.

pub fn iter_blk_trait<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockTrait<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_interface<'a>( &'a self, id: usize, ) -> Option<&'a BlockInterface<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_interface(&self) -> usize

Get count of items.

pub fn iter_blk_interface<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockInterface<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_impl<'a>(&'a self, id: usize) -> Option<&'a BlockImpl<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_impl(&self) -> usize

Get count of items.

pub fn iter_blk_impl<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockImpl<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_call<'a>(&'a self, id: usize) -> Option<&'a BlockCall<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_call(&self) -> usize

Get count of items.

pub fn iter_blk_call<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockCall<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_enum<'a>(&'a self, id: usize) -> Option<&'a BlockEnum<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_enum(&self) -> usize

Get count of items.

pub fn iter_blk_enum<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockEnum<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_field<'a>(&'a self, id: usize) -> Option<&'a BlockField<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_field(&self) -> usize

Get count of items.

pub fn iter_blk_field<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockField<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_const<'a>(&'a self, id: usize) -> Option<&'a BlockConst<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_const(&self) -> usize

Get count of items.

pub fn iter_blk_const<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockConst<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_parameter<'a>( &'a self, id: usize, ) -> Option<&'a BlockParameter<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_parameter(&self) -> usize

Get count of items.

pub fn iter_blk_parameter<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockParameter<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_return<'a>(&'a self, id: usize) -> Option<&'a BlockReturn<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_return(&self) -> usize

Get count of items.

pub fn iter_blk_return<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockReturn<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_blk_alias<'a>(&'a self, id: usize) -> Option<&'a BlockAlias<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_blk_alias(&self) -> usize

Get count of items.

pub fn iter_blk_alias<'a>( &'a self, ) -> impl Iterator<Item = &'a BlockAlias<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.