pub struct SymbolPtr(/* private fields */);Expand description
Thread-safe wrapper for raw Symbol pointer. SAFETY: The Symbol is allocated in a bump arena that outlives all usage, and Symbols are immutable after creation (interior mutability via atomics).
Implementations