pub struct InternPool { /* private fields */ }Expand description
Shared string interner used across the llmcc core.
Thread-safe wrapper around InternPoolInner using Arc for shared ownership.
Implementations
Sourceimpl InternPool
impl InternPool
Sourcepub fn intern<S>(&self, value: S) -> InternedStr
pub fn intern<S>(&self, value: S) -> InternedStr
Intern the provided string slice and return its symbol.
Sourcepub fn intern_batch<S>(
&self,
values: impl IntoIterator<Item = S>,
) -> Vec<InternedStr> ⓘ
pub fn intern_batch<S>( &self, values: impl IntoIterator<Item = S>, ) -> Vec<InternedStr> ⓘ
Intern multiple strings and return a vector of their symbols.
Sourcepub fn resolve_owned(&self, symbol: InternedStr) -> Option<String>
pub fn resolve_owned(&self, symbol: InternedStr) -> Option<String>
Resolve an interned symbol back into an owned string.
Clones the underlying string from the interner to avoid lifetime issues.
Sourcepub fn with_resolved<R, F>(&self, symbol: InternedStr, f: F) -> Option<R>
pub fn with_resolved<R, F>(&self, symbol: InternedStr, f: F) -> Option<R>
Resolve an interned symbol and apply a closure while the borrow is active.