ArenaInner

Struct ArenaInner 

pub struct ArenaInner {
    pub herd: Herd,
    pub hir_node: DashMap<usize, *const ()>,
    pub hir_file: DashMap<usize, *const ()>,
    pub hir_text: DashMap<usize, *const ()>,
    pub hir_internal: DashMap<usize, *const ()>,
    pub hir_scope: DashMap<usize, *const ()>,
    pub hir_ident: DashMap<usize, *const ()>,
    pub scope: DashMap<usize, *const ()>,
    pub symbol: DashMap<usize, *const ()>,
}
The actual data container: thread-safe, allocation-aware. Uses ’static lifetime for storage since we use raw pointers internally.

Fields

herd: Herdhir_node: DashMap<usize, *const ()>hir_file: DashMap<usize, *const ()>hir_text: DashMap<usize, *const ()>hir_internal: DashMap<usize, *const ()>hir_scope: DashMap<usize, *const ()>hir_ident: DashMap<usize, *const ()>scope: DashMap<usize, *const ()>symbol: DashMap<usize, *const ()>

Implementations

Source

impl ArenaInner

pub fn new() -> Self

Create a fresh ArenaInner.

pub fn new_with_capacity(cap: usize) -> Self

Create ArenaInner with pre-allocated capacity for each field.

pub fn reset(&mut self)

Clear all allocations and reset memory.

pub fn alloc_with_id<'a, T: ArenaInsertWithId<'a>>( &'a self, id: usize, value: T, ) -> &'a T

Thread-safe allocation with ID for lookup. Allocates in bump arena and inserts into DashMap.

pub fn alloc<'a, T: ArenaInsert<'a>>(&'a self, value: T) -> &'a T

Thread-safe allocation without ID tracking. Just allocates in bump arena, no DashMap insert.

pub fn alloc_in_herd<T>(&self, value: T) -> &T

Allocate a value in the thread-local bump allocator. Uses thread_local to cache the Member per thread, avoiding mutex contention.

pub fn alloc_str(&self, src: &str) -> &str

Allocate a string in the thread-local bump allocator. Returns a reference to the arena-allocated string, avoiding heap allocation.

pub fn get_hir_node<'a>(&'a self, id: usize) -> Option<&'a HirNode<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_hir_node(&self) -> usize

Get count of items.

pub fn iter_hir_node<'a>(&'a self) -> impl Iterator<Item = &'a HirNode<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_hir_file<'a>(&'a self, id: usize) -> Option<&'a HirFile>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_hir_file(&self) -> usize

Get count of items.

pub fn iter_hir_file<'a>(&'a self) -> impl Iterator<Item = &'a HirFile> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_hir_text<'a>(&'a self, id: usize) -> Option<&'a HirText<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_hir_text(&self) -> usize

Get count of items.

pub fn iter_hir_text<'a>(&'a self) -> impl Iterator<Item = &'a HirText<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_hir_internal<'a>(&'a self, id: usize) -> Option<&'a HirInternal>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_hir_internal(&self) -> usize

Get count of items.

pub fn iter_hir_internal<'a>( &'a self, ) -> impl Iterator<Item = &'a HirInternal> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_hir_scope<'a>(&'a self, id: usize) -> Option<&'a HirScope<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_hir_scope(&self) -> usize

Get count of items.

pub fn iter_hir_scope<'a>( &'a self, ) -> impl Iterator<Item = &'a HirScope<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_hir_ident<'a>(&'a self, id: usize) -> Option<&'a HirIdent<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_hir_ident(&self) -> usize

Get count of items.

pub fn iter_hir_ident<'a>( &'a self, ) -> impl Iterator<Item = &'a HirIdent<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_scope<'a>(&'a self, id: usize) -> Option<&'a Scope<'a>>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_scope(&self) -> usize

Get count of items.

pub fn iter_scope<'a>(&'a self) -> impl Iterator<Item = &'a Scope<'a>> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.

pub fn get_symbol<'a>(&'a self, id: usize) -> Option<&'a Symbol>

Get item by ID from DashMap (O(1) concurrent lookup). SAFETY: The pointer was allocated from the bump arena and is valid for the arena’s lifetime.

pub fn len_symbol(&self) -> usize

Get count of items.

pub fn iter_symbol<'a>(&'a self) -> impl Iterator<Item = &'a Symbol> + 'a

Iterate over all items (for compatibility). SAFETY: All pointers are valid for the arena’s lifetime.