pub struct UnitMeta {
pub project_name: Option<String>,
pub project_root: Option<PathBuf>,
pub package_name: Option<String>,
pub package_root: Option<PathBuf>,
pub module_name: Option<String>,
pub module_root: Option<PathBuf>,
pub file_name: Option<String>,
pub file_path: Option<PathBuf>,
pub crate_index: usize,
}Expand description
Complete location info for a source file at all 4 depths.
Fields
project_name: Option<String>project_root: Option<PathBuf>package_name: Option<String>package_root: Option<PathBuf>module_name: Option<String>module_root: Option<PathBuf>file_name: Option<String>file_path: Option<PathBuf>crate_index: usizeUnique index for the crate/package this file belongs to. All files in the same crate share the same crate_index. Used for efficient same-crate preference during symbol lookup.
Implementations