pub struct PageRankConfig {
pub damping_factor: f64,
pub max_iterations: usize,
pub tolerance: f64,
pub relation: BlockRelation,
pub direction: PageRankDirection,
}Expand description
Configuration options for the PageRank algorithm.
Fields
damping_factor: f64Damping factor used when random walkers jump to a random node.
max_iterations: usizeMaximum number of iterations to run the algorithm.
tolerance: f64Convergence tolerance (L1 delta between successive rank vectors).
relation: BlockRelationWhich edge relation to consider when traversing the graph.
direction: PageRankDirectionEdge direction: follow DependsOn or DependedBy edges.