Scope

Struct Scope 

pub struct Scope<'tcx> { /* private fields */ }
Represents a single level in the scope hierarchy.

Implementations

Source

impl<'tcx> Scope<'tcx>

pub fn new(owner: HirId) -> Self

Creates a new scope owned by the given HIR node.

pub fn new_with( owner: HirId, symbol: Option<&'tcx Symbol>, interner: Option<&'tcx InternPool>, ) -> Self

Creates a new scope owned by the given HIR node and associated with a symbol.

pub fn new_with_shards( owner: HirId, symbol: Option<&'tcx Symbol>, interner: Option<&'tcx InternPool>, shard_count: usize, ) -> Self

Creates a new scope with specified shard count for the DashMap. Use this for high-contention scopes like globals.

pub fn merge_with(&self, other: &'tcx Scope<'tcx>, _arena: &'tcx Arena<'tcx>)

Merge existing scope into this scope.

pub fn add_parent(&self, parent: &'tcx Scope<'tcx>)

pub fn owner(&self) -> HirId

pub fn set_symbol(&self, symbol: &'tcx Symbol)

pub fn opt_symbol(&self) -> Option<&'tcx Symbol>

pub fn find_parent_by_kind(&self, kind: SymKind) -> Option<&'tcx Symbol>

Find a parent scope with a symbol of the given kind. Walks up the parent chain (BFS) looking for a scope whose symbol matches.

pub fn id(&self) -> ScopeId

pub fn get_redirect(&self) -> Option<ScopeId>

If this scope was redirected (merged into another), get the target scope ID.

pub fn set_redirect(&self, target: ScopeId)

Set the redirect for this scope (used when merging scopes).

pub fn parents(&self) -> Vec<&'tcx Scope<'tcx>>

pub fn for_each_symbol<F>(&self, visit: F)
where F: FnMut(&'tcx Symbol),

Invokes a closure for each symbol in this scope. Iterates in deterministic order by sorting keys.

pub fn insert(&self, symbol: &'tcx Symbol) -> SymId

Inserts a symbol into this scope.

pub fn lookup_symbols( &self, name: InternedStr, options: LookupOptions, ) -> Option<Vec<&'tcx Symbol>>