pub struct InternPool { /* private fields */ }Expand description
Shared string interner used across the llmcc core.
Implementations
Sourceimpl InternPool
impl InternPool
Sourcepub fn intern<S>(&self, value: S) -> InternedStr
pub fn intern<S>(&self, value: S) -> InternedStr
Intern the provided string slice and return its symbol.
Sourcepub fn resolve_owned(&self, symbol: InternedStr) -> Option<String>
pub fn resolve_owned(&self, symbol: InternedStr) -> Option<String>
Resolve an interned symbol back into an owned string.
Clones the underlying string from the interner to avoid lifetime issues.
Sourcepub fn with_resolved<R, F>(&self, symbol: InternedStr, f: F) -> Option<R>
pub fn with_resolved<R, F>(&self, symbol: InternedStr, f: F) -> Option<R>
Resolve an interned symbol and apply a closure while the borrow is active.