HirNode

Enum HirNode 

pub enum HirNode<'hir> {
    Undefined,
    Root(&'hir HirRoot<'hir>),
    Text(&'hir HirText<'hir>),
    Internal(&'hir HirInternal<'hir>),
    Scope(&'hir HirScope<'hir>),
    File(&'hir HirFile<'hir>),
    Ident(&'hir HirIdent<'hir>),
}

Variants



Undefined



Root(&'hir HirRoot<'hir>)



Text(&'hir HirText<'hir>)



Internal(&'hir HirInternal<'hir>)



Scope(&'hir HirScope<'hir>)



File(&'hir HirFile<'hir>)



Ident(&'hir HirIdent<'hir>)

Implementations

Source

impl<'hir> HirNode<'hir>

pub fn format_node(&self, unit: CompileUnit<'hir>) -> String

pub fn base(&self) -> Option<&HirBase<'hir>>

Get the base information for any HIR node

pub fn kind(&self) -> HirKind

Get the kind of this HIR node

pub fn is_kind(&self, kind: HirKind) -> bool

Check if this node is of a specific kind

pub fn field_id(&self) -> u16

pub fn children(&self) -> &[HirId]

Get children of this node

pub fn kind_id(&self) -> u16

pub fn hir_id(&self) -> HirId

pub fn start_byte(&self) -> usize

pub fn end_byte(&self) -> usize

pub fn child_count(&self) -> usize

pub fn inner_ts_node(&self) -> Node<'hir>

pub fn parent(&self) -> Option<HirId>

pub fn opt_child_by_field( &self, unit: CompileUnit<'hir>, field_id: u16, ) -> Option<HirNode<'hir>>

pub fn child_by_field( &self, unit: CompileUnit<'hir>, field_id: u16, ) -> HirNode<'hir>

pub fn expect_ident_child_by_field( &self, unit: CompileUnit<'hir>, field_id: u16, ) -> &'hir HirIdent<'hir>

pub fn opt_child_by_kind( &self, unit: CompileUnit<'hir>, kind_id: u16, ) -> Option<HirNode<'hir>>

pub fn child_by_kind( &self, unit: CompileUnit<'hir>, kind_id: u16, ) -> HirNode<'hir>

pub fn find_ident( &self, unit: CompileUnit<'hir>, ) -> Option<&'hir HirIdent<'hir>>

Recursively search for an identifier within this node.

Useful for finding the actual identifier in complex AST nodes like generic_type that wrap the identifier. For example, in impl<'tcx> Holder<'tcx>, the type field points to a generic_type node, which contains the type_identifier “Holder”.

Source

impl<'hir> HirNode<'hir>

pub fn as_root(&self) -> Option<&'hir HirRoot<'hir>>

pub fn expect_root(&self) -> &'hir HirRoot<'hir>

pub fn is_root(&self) -> bool

pub fn as_text(&self) -> Option<&'hir HirText<'hir>>

pub fn expect_text(&self) -> &'hir HirText<'hir>

pub fn is_text(&self) -> bool

pub fn as_internal(&self) -> Option<&'hir HirInternal<'hir>>

pub fn expect_internal(&self) -> &'hir HirInternal<'hir>

pub fn is_internal(&self) -> bool

pub fn as_scope(&self) -> Option<&'hir HirScope<'hir>>

pub fn expect_scope(&self) -> &'hir HirScope<'hir>

pub fn is_scope(&self) -> bool

pub fn as_file(&self) -> Option<&'hir HirFile<'hir>>

pub fn expect_file(&self) -> &'hir HirFile<'hir>

pub fn is_file(&self) -> bool

pub fn as_ident(&self) -> Option<&'hir HirIdent<'hir>>

pub fn expect_ident(&self) -> &'hir HirIdent<'hir>

pub fn is_ident(&self) -> bool