pub struct ScopeStack<'tcx> { /* private fields */ }Expand description
Manages a stack of nested scopes for symbol resolution and insertion.
Implementations
Sourceimpl<'tcx> ScopeStack<'tcx>
impl<'tcx> ScopeStack<'tcx>
pub fn new(arena: &'tcx Arena<'tcx>, interner: &'tcx InternPool) -> Self
pub fn depth(&self) -> usize
pub fn push(&self, scope: &'tcx Scope<'tcx>)
pub fn globals(&self) -> &'tcx Scope<'tcx>
pub fn top(&self) -> Option<&'tcx Scope<'tcx>>
Sourcepub fn push_recursive(&self, scope: &'tcx Scope<'tcx>)
pub fn push_recursive(&self, scope: &'tcx Scope<'tcx>)
Recursively pushes a scope and all its base (parent) scopes onto the stack.
pub fn pop(&self) -> Option<&'tcx Scope<'tcx>>
pub fn pop_until(&self, depth: usize)
Sourcepub fn lookup_symbols(
&self,
name: &str,
options: LookupOptions,
) -> Option<Vec<&'tcx Symbol>>
pub fn lookup_symbols( &self, name: &str, options: LookupOptions, ) -> Option<Vec<&'tcx Symbol>>
This should be the only pure api to lookup symbols following the lexical scope backwards.
Sourcepub fn lookup_or_insert(
&self,
name: &str,
node: HirId,
options: LookupOptions,
) -> Option<Vec<&'tcx Symbol>>
pub fn lookup_or_insert( &self, name: &str, node: HirId, options: LookupOptions, ) -> Option<Vec<&'tcx Symbol>>
Internal implementation for lookup/insert logic. This is the only entry point to create a symbol
Sourcepub fn lookup_qualified(
&self,
qualified_name: &[&str],
options: LookupOptions,
) -> Option<Vec<&'tcx Symbol>>
pub fn lookup_qualified( &self, qualified_name: &[&str], options: LookupOptions, ) -> Option<Vec<&'tcx Symbol>>
Lookup a qualified name like crate::foo::bar by resolving each part sequentially.
Starts from the global (first) scope and follows the scope chain through the symbol hierarchy.